@@ -1,4 +1,3 @@
-
 test_that("language() works", {
   expect_equal(language(iris_dataset), "en")
 })
@@ -7,21 +6,23 @@ myiris <- iris_dataset
 value <- "fr"
 
 test_that("language() works", {
-  language(x=myiris) <- "fr"
+  language(x = myiris) <- "fr"
   expect_equal(language(myiris), "fra")
 })
 
 
 test_that("language() works", {
-  language(x=myiris, iso_639_code = "639-1") <- "fr"
+  language(x = myiris, iso_639_code = "639-1") <- "fr"
   expect_equal(language(myiris), "fr")
 })
 
 test_that("language() works", {
-  language(x=myiris, iso_639_code = "639-1") <- "FR"
+  language(x = myiris, iso_639_code = "639-1") <- "FR"
   expect_equal(language(myiris), "fr")
 })
 
 test_that("language()<- throws error", {
-  expect_error(language(x=myiris) <- "hello")
+  expect_error(language(x = myiris) <- "hello",
+    regexp = "Language=hello is not a valid ISO 639 language code"
+  )
 })
